==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property audioRenditionSets
 * @property nielsenId3Behavior
 * @property timedMetadataBehavior
 */
public data class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs(
    public val audioRenditionSets: Output<String>? = null,
    public val nielsenId3Behavior: Output<String>? = null,
    public val timedMetadataBehavior: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs> {
    override fun toJava():
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs.builder()
            .audioRenditionSets(audioRenditionSets?.applyValue({ args0 -> args0 }))
            .nielsenId3Behavior(nielsenId3Behavior?.applyValue({ args0 -> args0 }))
            .timedMetadataBehavior(timedMetadataBehavior?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgsBuilder
internal constructor() {
    private var audioRenditionSets: Output<String>? = null

    private var nielsenId3Behavior: Output<String>? = null

    private var timedMetadataBehavior: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("wuvmrsqocdedfhsb")
    public suspend fun audioRenditionSets(`value`: Output<String>) {
        this.audioRenditionSets = value
    }

    /**
     * @param value
     */
    @JvmName("mxtsimawfvifohgm")
    public suspend fun nielsenId3Behavior(`value`: Output<String>) {
        this.nielsenId3Behavior = value
    }

    /**
     * @param value
     */
    @JvmName("ekvbfabxqyddgotw")
    public suspend fun timedMetadataBehavior(`value`: Output<String>) {
        this.timedMetadataBehavior = value
    }

    /**
     * @param value
     */
    @JvmName("iymnkylpknrrapds")
    public suspend fun audioRenditionSets(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audioRenditionSets = mapped
    }

    /**
     * @param value
     */
    @JvmName("wkkhbgpffcxsqwij")
    public suspend fun nielsenId3Behavior(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nielsenId3Behavior = mapped
    }

    /**
     * @param value
     */
    @JvmName("jacssvirhvpyywxh")
    public suspend fun timedMetadataBehavior(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timedMetadataBehavior = mapped
    }

    internal fun build():
        ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs =
        ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs(
            audioRenditionSets = audioRenditionSets,
            nielsenId3Behavior = nielsenId3Behavior,
            timedMetadataBehavior = timedMetadataBehavior,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property audioRenditionSets
 * @property nielsenId3Behavior
 * @property timedMetadataBehavior
 */
public data class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs(
    public val audioRenditionSets: Output<String>? = null,
    public val nielsenId3Behavior: Output<String>? = null,
    public val timedMetadataBehavior: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs> {
    override fun toJava(): com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs.builder()
            .audioRenditionSets(audioRenditionSets?.applyValue({ args0 -> args0 }))
            .nielsenId3Behavior(nielsenId3Behavior?.applyValue({ args0 -> args0 }))
            .timedMetadataBehavior(timedMetadataBehavior?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgsBuilder
internal constructor() {
    private var audioRenditionSets: Output<String>? = null

    private var nielsenId3Behavior: Output<String>? = null

    private var timedMetadataBehavior: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("ejdnuvtsvhmiuffl")
    public suspend fun audioRenditionSets(`value`: Output<String>) {
        this.audioRenditionSets = value
    }

    /**
     * @param value
     */
    @JvmName("bujihqlcdfconfws")
    public suspend fun nielsenId3Behavior(`value`: Output<String>) {
        this.nielsenId3Behavior = value
    }

    /**
     * @param value
     */
    @JvmName("wbuulvlassbqwugr")
    public suspend fun timedMetadataBehavior(`value`: Output<String>) {
        this.timedMetadataBehavior = value
    }

    /**
     * @param value
     */
    @JvmName("smbmgucremnfyanh")
    public suspend fun audioRenditionSets(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audioRenditionSets = mapped
    }

    /**
     * @param value
     */
    @JvmName("clmqkichgbpmeowy")
    public suspend fun nielsenId3Behavior(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nielsenId3Behavior = mapped
    }

    /**
     * @param value
     */
    @JvmName("ohuuolslyugsmier")
    public suspend fun timedMetadataBehavior(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timedMetadataBehavior = mapped
    }

    internal fun build(): ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs =
        ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsFmp4HlsSettingsArgs(
            audioRenditionSets = audioRenditionSets,
            nielsenId3Behavior = nielsenId3Behavior,
            timedMetadataBehavior = timedMetadataBehavior,
        )
}
